@@ -25,30 +25,37 @@ class XGBoostClassifier:
     want to train a model on the whole data and test on a separate
     validation set. Main reference is XGBoost Python API:
     (https://xgboost.readthedocs.io/en/latest/python/python_api.html)
+
     Parameters
     ----------
     num_boost_round: int, optional (default=200)
         Number of boosting round to train the model
+
     metrics: str or tuple[str], optional (default=("auc"))
         Metric used for evaluation at cross-validation
         using xgboost.cv(). Please note that this is different
         than eval_metric that needs to be passed to params dict.
         Possible values are "auc", "aucpr", "error", "logloss"
+
     sparse_matrix: bool, optional (default=False)
         Flag to convert data to sparse matrix with csr format.
         This would increase the speed of feature selection for
         relatively large datasets
+
     scale_mean: bool, optional (default=False)
         Flag to center the data before scaling. This flag should be
         False when using sparse_matrix=True, since it centering the data
         would decrease the sparsity and in practice it does not make any
         sense to use sparse matrix method and it would make it worse.
+
     scale_std: bool, optional (default=False)
         Flag to scale the data to unit variance
         (or equivalently, unit standard deviation)
+
     importance_type: str, optional (default="total_gain")
         Importance type of xgboost.train() with possible values
         "weight", "gain", "total_gain", "cover", "total_cover"
+
     params: dict, optional
         Set of parameters for evaluation of xboost.train()
         (default={"eval_metric" : "auc",
@@ -72,38 +79,56 @@ class XGBoostClassifier:
         Returns a dict() of all feature importance based on
         importance_type at each fold of each iteration during
         selection process
+
     scaler_: StandardScaler object
         Returns the scaler object if any of scale_mean or scale_std
         was passed True.
-    X_train_: Pandas DataFrame()
+
+    X_train_: pandas.DataFrame
         Returns scaled training data set that passed if if any of
         scale_mean or scale_std was passed as True, else X_train.
-    X_test_: Pandas DataFrame()
+
+    X_test_: pandas.DataFrame
         Returns transformed testing data set using scaler_ object if if any of
         scale_mean or scale_std was passed as True, else X_train.
+
     d_train_: xgboost.DMatrix object
         Returns the xgboost.DMatrix(X_train_, y_train)
+
     d_test_: xgboost.DMatrix object
         Returns the xgboost.DMatrix(X_test_, y_test)
-    shap_values_train_: Numpy array
+
+    shap_values_train_: numpy.array
         SHAP values from treeExplainer using X_train
-    shap_values_test_: Numpy array
+
+    shap_values_test_: numpy.array
         SHAP values from treeExplainer using X_test
-    fit(X_train, y_train): class method
+
+    fit(X_train, y_train): instance method
         Returns None and applies the training process using
         the (X_train, y_train) set using xgboost.train()
-    predict_proba(X_test, y_test): class method
+
+    predict_proba(X_test, y_test): instance method
         Return the prediction probabilities for positive classes. Please note that
         it only reports the probability of the positive class, while the sklearn
         one returns for both and slicing like pred_proba[:, 1]
         is needed for positive class predictions
-    get_params(): class method
+
+    predict(X_test, y_test, threshold=0.5): instance method
+        Return the prediction classes based on the passed threshold.
+        The default threshold is set at 0.5 while you can find the optimum thresholds
+        based on different methods using BinaryClassificationMetrics.
+
+    get_params(): instance method
         Returns params dict
-    get_feature_importance(): class method
+
+    get_feature_importance(): instance method
         Returns feature importance based on importance_type
-    plot_feature_importance(): class method
+
+    plot_feature_importance(): instance method
         Plots feature importance
-    plot_shap_summary(): class method
+
+    plot_shap_summary(): instance method
         Plot shap values summary
     """
 
@@ -197,10 +222,12 @@ class XGBoostClassifier:
         input parameters including sparse_matrix,
         and scaled using both numpy array and pandas
         DataFrame.
+
         Parameters
         ----------
-        X_train: numpy.array or Pandas DataFrame
+        X_train: numpy.array or pandas.DataFrame
             Training features data
+
         y_train: numpy.array[int] or list[int]
             List of training ground truth binary values [0, 1]
         """
@@ -256,10 +283,12 @@ class XGBoostClassifier:
         in case it was used. Please note that y_test is
         optional since it might not be available while
         validating the model.
+
         Parameters
         ----------
-        X_test: numpy.array or Pandas DataFrame
+        X_test: numpy.array or pandas.DataFrame
             Testing/validation features data
+
         y_test: numpy.array[int] or list[int], optional (default=None)
             List of testing/validation ground truth binary values [0, 1]
         """
@@ -334,6 +363,14 @@ class XGBoostClassifier:
         Function to run xgboost.train() method based on the given number of
         boosting round from the inputs using (X_train, y_train) set
         and returns it.
+
+        Parameters
+        ----------
+        X_train: numpy.array or pandas.DataFrame
+            Training features data
+
+        y_train: numpy.array[int] or list[int]
+            List of training ground truth binary values [0, 1]
         """
         # creating dtrain
         self.dtrain_ = self._dtrain(X_train, y_train)
@@ -368,10 +405,12 @@ class XGBoostClassifier:
         while the sklearn one returns for both and slicing like pred_proba[:, 1]
         is needed for positive class predictions. Note that y_test is optional while
         it might not be available in validiation.
+
         Parameters
         ----------
-        X_test: numpy.array or Pandas DataFrame
+        X_test: numpy.array or pandas.DataFrame
             Validation features data
+
         y_test: numpy.array[int] or list[int], optional (default=None)
             List of validation ground truth binary values [0, 1]
         """
@@ -385,12 +424,15 @@ class XGBoostClassifier:
         Function to return the prediction classes based on the passed threshold.
         The default threshold is set at 0.5 while you can find the optimum thresholds
         based on different methods using BinaryClassificationMetrics.
+
         Parameters
         ----------
-        X_test: numpy.array or Pandas DataFrame
+        X_test: numpy.array or pandas.DataFrame
             Validation features data
+
         y_test: numpy.array[int] or list[int], optional (default=None)
             List of validation ground truth binary values [0, 1]
+
         threshold: float, optional (default=0.5)
             Threshold to define classes based on probabilities.
             predict_proba >= threshold would be defined as 1 else 0.
@@ -416,26 +458,35 @@ class XGBoostClassifier:
         """Function to plot XGBoost feature importance.
         This function is a helper function based on the feature_importance_
         attribute of the XGBoostCVClassifier class.
+
         Parameters
         ----------
         feature importance: Pandas DataFrame
             Feature frequency
+
         figsize: tuple, optional, (default=(8, 5))
             Figure size
+
         color: str, optional, (default="#87CEEB")
             Color of the vertical lines of lollipops
+
         marker: str, optional, (default="o")
             Market style of the lollipops. Complete valid
             marker styke can be found at:
             (https://matplotlib.org/2.1.1/api/markers_api.html#module-matplotlib.markers)
+
         markersize: int or float, optional, (default=10)
             Markersize
+
         markeredgecolor: str, optional, (default="1F77B4")
             Marker edge color
+
         markerfacecolor: str, optional, (default="1F77B4")
             Marker face color
+
         markeredgewidth: int or float, optional, (default=1)
             Marker edge width
+
         fontsize: int or float, optional, (default=12)
             Fontsize for xlabel and ylabel, and ticks parameters
         """
@@ -474,40 +525,54 @@ class XGBoostClassifier:
         based on all types of shap explainers including tree, linear, and dnn.
         Please note that this function should be ran after the predict_proba to
         make sure the X_test is being instansiated.
+
         Parameters
         ----------
         validation: bool, optional, (default=True)
             Flag to calculate SHAP values of X_test if it is True.
             If validation=False, it calculates the SHAP values of
             X_train and plots the summary plot.
+
         plot_type: str, optional (single-output default="dot", multi-output default="bar")
             The type of summar plot. Options are "bar", "dot", "violin", "layered_violin",
             and "compact_dot" which is recommended for SHAP interactions
+
         figsize: tuple, optional, (default="auto")
             Figure size
+
         color: str, optional, (default= "#D0AAF3" for "bar")
             Color of violin and layered violin plots are "RdBl" cmap
             Color of the horizontal lines when plot_type="bar" is "#D0AAF3"
+
         max_display: int, optional, (default=20)
             Limit to show the number of features in the plot
+
         feature_names: str, optional, (default=None)
             List of feature names to pass. It should follow the order
             of fatures
+
         title: str, optional, (default=None)
             Title of the plot
+
         show: bool, optional, (default=True)
             Flag to show the plot in inteactive environment
+
         sort: bool, optional, (default=True)
             Flag to plot sorted shap vlues in descending order
+
         color_bar: bool, optional, (default=True)
             Flag to show color_bar when plot_type is "dot" or "violin"
+
         layered_violin_max_num_bins: int, optional, (default=10)
             The number of bins for calculating the violin plots ranges
             and outliers
+
         class_names: list, optional, (default=None)
             List of class names for multi-output problems
+
         class_inds: list, optional, (default=True)
             List of class indices for multi-output problems
+
         color_bar_label: str, optional, (default="Feature Value")
             Label for color bar
         """
@@ -568,36 +633,49 @@ class XGBoostClassifier:
         Therefore, it can be easily seen with each feature how much explainability we
         can acheieve. Please note that this function should be ran after the predict_proba to
         make sure the X_test is being instansiated.
+
         Parameters
         ----------
         validation: bool, optional, (default=True)
             Flag to calculate SHAP values of X_test if it is True.
             If validation=False, it calculates the SHAP values of
             X_train and plots the summary plot.
+
         figsize: tuple, optional, (default=(8, 5))
             Figure size
+
         bar_color: str, optional, (default="#B3C3F3")
             Color of the horizontal bar lines
+
         bar_thickness: float, optional, (default=0.5)
             Thickness (hight) of the horizontal bar lines
+
         line_color: str, optional, (default="purple")
             Color of the line plot
+
         marker: str, optional, (default="o")
             Marker style
             marker style can be found at:
             (https://matplotlib.org/2.1.1/api/markers_api.html#module-matplotlib.markers)
+
         markersize: int or float, optional, (default=7)
             Markersize
+
         markeredgecolor: str, optional, (default="purple")
             Marker edge color
+
         markerfacecolor: str, optional, (default="purple")
             Marker face color
+
         markeredgewidth: int or float, optional, (default=1)
             Marker edge width
+
         max_display: int, optional, (default=20)
             Limit to show the number of features in the plot
+
         title: str, optional, (default=None)
             Title of the plot
+
         fontsize: int or float, optional, (default=12)
             Fontsize for xlabel and ylabel, and ticks parameters
         """
@@ -646,44 +724,56 @@ class XGBoostCVClassifier(XGBoostClassifier):
     set decrease the possibility of over-fitting.
     run xgboost.train(). Main reference is XGBoost Python API:
     (https://xgboost.readthedocs.io/en/latest/python/python_api.html)
+
     Parameters
     ----------
     num_boost_round: int, optional (default=200)
         Number of boosting round at each fold of xgboost.cv()
+
     n_splits: int, optional (default=4)
         Number of folds for cross-validation
+
     metrics: str or tuple[str], optional (default=("auc"))
         Metric used for evaluation at cross-validation
         using xgboost.cv(). Please note that this is different
         than eval_metric that needs to be passed to params dict.
         Possible values are "auc", "aucpr", "error", "logloss"
+
     early_stopping_rounds: int, optional (default=20)
         The criterion to early abort the xgboost.cv() phase
         if the test metric is not improved
+
     random_state: int, optional (default=1367)
         Random seed
+
     stratified: bool, optional (default=True)
         Flag to stratificaiton of the targets to run xgboost.cv() to
         find the best number of boosting round at each fold of
         each iteration
+
     shuffle: bool, optional (default=True)
         Flag to shuffle data to have the ability of building
         stratified folds in xgboost.cv()
+
     sparse_matrix: bool, optional (default=False)
         Flag to convert data to sparse matrix with csr format.
         This would increase the speed of feature selection for
         relatively large datasets
+
     scale_mean: bool, optional (default=False)
         Flag to center the data before scaling. This flag should be
         False when using sparse_matrix=True, since it centering the data
         would decrease the sparsity and in practice it does not make any
         sense to use sparse matrix method and it would make it worse.
+
     scale_std: bool, optional (default=False)
         Flag to scale the data to unit variance
         (or equivalently, unit standard deviation)
+
     importance_type: str, optional (default="total_gain")
         Importance type of xgboost.train() with possible values
         "weight", "gain", "total_gain", "cover", "total_cover"
+
     params: dict, optional
         Set of parameters for evaluation of xboost.train()
         (default={"eval_metric" : "auc",
@@ -700,9 +790,11 @@ class XGBoostCVClassifier(XGBoostClassifier):
                   "verbosity" : 0,
                   "nthread" : 4,
                   "scale_pos_weight" : 1})
+
     callbacks: bool, optional (default=False)
         Flag for printing results during xgboost.cv().
         This would help to track the early stopping criterion
+
     verbose: bool, optional (default=False)
         Flag to show the final results of xgboost.cv()
 
@@ -712,50 +804,72 @@ class XGBoostCVClassifier(XGBoostClassifier):
         Returns a dict() of all feature importance based on
         importance_type at each fold of each iteration during
         selection process
+
     feature_frequency_: Pandas DataFrame()
         Returns a DataFrame() cosists of total frequency of
         each feature during the selection process
+
     cv_results_: Pandas DataFrame()
         Return a Pandas DataFrame() of the mean value of the metrics
-        in n-folds cross-validation for each boosting round
+
+        n n-folds cross-validation for each boosting round
     scaler_: StandardScaler object
         Returns the scaler object if any of scale_mean or scale_std
         was passed True.
+
     X_train_: Pandas DataFrame()
         Returns scaled training data set that passed if if any of
         scale_mean or scale_std was passed as True, else X_train.
+
     X_test_: Pandas DataFrame()
         Returns transformed testing data set using scaler_ object if if any of
         scale_mean or scale_std was passed as True, else X_train.
+
     d_train_: xgboost.DMatrix object
         Returns the xgboost.DMatrix(X_train_, y_train)
+
     d_test_: xgboost.DMatrix object
         Returns the xgboost.DMatrix(X_test_, y_test)
+
     shap_values_train_: Numpy array
         SHAP values from treeExplainer using X_train
+
     shap_values_test_: Numpy array
         SHAP values from treeExplainer using X_test
-    fit(X_train, y_train): class method
+
+    fit(X_train, y_train): instance method
         Returns None and applies the training process using
         the (X_train, y_train) set using xgboost.cv() and xgboost.train()
-    predict_proba(X_test, y_test): class method
+
+    predict_proba(X_test, y_test): instance method
         Return the prediction probabilities for positive classes. Please note that
         it only reports the probability of the positive class, while the sklearn
         one returns for both and slicing like pred_proba[:, 1]
         is needed for positive class predictions
-    get_params(): class method
+
+    predict(X_test, y_test, threshold=0.5): instance method
+        Return the prediction classes based on the passed threshold.
+        The default threshold is set at 0.5 while you can find the optimum thresholds
+        based on different methods using BinaryClassificationMetrics.
+
+    get_params(): instance method
         Returns params dict
-    get_feature_importance(): class method
+
+    get_feature_importance(): instance method
         Returns feature importance based on importance_type
         at each fold of each iteration of the selection process
-    get_cv_results(): class method
+
+    get_cv_results(): instance method
         Return a Pandas DataFrame() of the mean value of the metrics
         in n-folds cross-validation for each boosting round
-    plot_cv_results(): class method
+
+    plot_cv_results(): instance method
         Plot cross-validation results
-    plot_feature_importance(): class method
+
+    plot_feature_importance(): instance method
         Plots feature importance
-    plot_shap_summary(): class method
+
+    plot_shap_summary(): instance method
         Plot shap values summary
     """
 
@@ -874,6 +988,14 @@ class XGBoostCVClassifier(XGBoostClassifier):
         """
         Function to run xgboost.cv() method first to find the best number of boosting round
         and train a model based on that on (X_train, y_train) set and returns it.
+
+        Parameters
+        ----------
+        X_train: numpy.array or pandas.DataFrame
+            Training features data
+
+        y_train: numpy.array[int] or list[int]
+            List of training ground truth binary values [0, 1]
         """
         # creating dtrain, dtest (dtest here for the sake of plotting)
         self.dtrain_ = self._dtrain(X_train, y_train)
@@ -940,25 +1062,34 @@ class XGBoostCVClassifier(XGBoostClassifier):
         """
         Function to plot the results of xgboost.cv() process and evolution
         of metrics through number of boosting rounds.
+
         Parameters
         ----------
         cv_results: Pandas DataFrame()
             Cross-validation results in DataFrame() format
+
         figsize: tuple, optional, (default=(8, 5))
             Figure size
+
         linestyle: str, optional, (default="--")
             Style of lines. Complete options are available at
             (https://matplotlib.org/3.1.0/gallery/lines_bars_and_markers/linestyles.html)
+
         train_label: str, optional (default="Train")
             Label in the figure legend for the training line
+
         test_label: str, optional (default="Test")
             Label in the figure legend for the training line
+
         train_color: str, optional, (default="navy")
             Color of the training line
+
         train_std_color: str, optional, (default="#B3C3F3")
             Color of the edge color of the training std bars
+
         test_color: str, optional, (default="purple")
             Color of the testing line
+
         test_std_color: str, optional, (default="#D0AAF3")
             Color of the edge color of the testing std bars
         """
@@ -981,19 +1112,23 @@ class GLMNetCVClassifier:
     This is wrapper using GLM-Net to train a Regularized Linear Model
     via logitic regression and find the optimal penalty values through
     N-Folds cross validation. This function is pretty useful to train
-    a Elastic-Net model with the ability of feature reduction. Main
+    a Logit-Net model with the ability of feature reduction. Main
     theoretical reference:
     (https://web.stanford.edu/~hastie/glmnet/glmnet_alpha.html)
+
     Parameters
     ----------
     alpha: float, optional (default=0.5)
         The stability parameter, 0 <= alpha <= 1: 0.0 for Ridge, 1.0 for LASSO
+
     n_lambda: int, optional (default=100)
         Maximum number of lambda values to compute
+
     n_splits: int, optional (default=3)
         Number of cross validation folds for computing performance metrics and
         determining lambda_best_ and lambda_max_. If non-zero, must be
         at least 3.
+
     metric: str or callable, optional (default="roc_auc")
         Metric used for model selection during cross validation.
         Valid options are "accuracy", "roc_auc", "average_precision",
@@ -1002,36 +1137,46 @@ class GLMNetCVClassifier:
         Note, the metric function affects the selection of "lambda_best_" and
         "lambda_max_", fitting the same data ith different metric methods will result
         in the selection of different models.
+
     scale : bool, optional (default=True)
         Flag to standardize (mean of 0.0 and std of 1) input features prior to fitting.
         The final coefficients will be on the scale of the original data regardless
         of the value of the scale flag.
+
     sparse_matrix: bool, optional (default=False)
         Flag to convert data to sparse matrix with csr format. This would increase
         the speed of feature selection for relatively large datasets. Note that when
         "scale=True", you would lose sparsity due to standardization process.
+
     fit_intercept : bool, optional (default=True)
         Include an intercept term in the model.
+
     cut_point : float, optional (default=1.0)
         The cut point to use for selecting lambda_best.
         Based on this value, the distance between "lambda_max" and "best_lambda"
         would be cut_point * standard_error(lambda_max)
         arg_max(lambda) for cv_score(lambda) >= cv_score(lambda_max) - cut_point * standard_error(lambda_max)
+
     min_lambda_ratio: float, optional (default=1e-4)
         In combination with "n_lambda", the ratio of the smallest and largest
         values of lambda computed (min_lambda/max_lambda >= min_lambda_ratio).
+
     lambda_path: array, optional (default=None)
         In place of supplying "n_lambda", provide an array of specific values
         to compute. The specified values must be in decreasing order. When
         None, the path of lambda values will be determined automatically. A
         maximum of "n_lambda" values will be computed.
+
     tol: float, optional (default=1e-7)
         Convergence tolerance
+
     max_iter: int, optional (default=100000)
         Maximum passes over the data
+
     random_state: int, optional (default=1367)
         Seed for the random number generator. The glmnet solver is not
         deterministic, this seed is used for determining the cv folds.
+
     max_features: int, optional (default=None)
         Optional maximum number of features with nonzero coefficients after
         regularization. If not set, defaults to X.shape[1] during fit
@@ -1039,51 +1184,67 @@ class GLMNetCVClassifier:
 
     Attributes
     ----------
-    X_train_: Pandas DataFrame()
+    X_train_: pandas.DataFrame()
         Returns training data set.
-    X_test_: Pandas DataFrame()
+
+    X_test_: pandas.DataFrame()
         Returns transformed testing data set.
-    y_train_: Numpy 1D array or list
-        Returns the training grounds truth classes
-    y_test_: Numpy 1D array or list
-        Returns the testing grounds truth classes
-    coeff_: Pandas DataFrame
+
+    y_train_: numpy.array[int] or list[int]
+        Returns the list of training ground truth binary values [0, 1]
+
+    y_test_: numpy.array[int] or list[int]
+        Returns the list of testing ground truth binary values [0, 1]
+
+    coeff_: pandas.DataFrame
         Return the model's non-zero coefficients
+
     intercept_: float
         Return the model's intercept
-    cv_results_: Pandas DataFrame()
+
+    cv_results_: pandas.DataFrame
         Returns the cross-validation results
+
     results_: dict()
         Returns the model's total results
+
     params_: dict()
         Returns model's fitting parameters
-    fit(X_train, y_train): class method
+
+    fit(X_train, y_train): instance method
         Returns None and applies the training process using
         the (X_train, y_train) set using glmnet.LogitNet()
-    predict_proba(X_test, y_test=None): class method
+
+    predict_proba(X_test, y_test=None): instance method
         Return the prediction probabilities for positive classes. Please note that
         it only reports the probability of the positive class, while the sklearn
         one returns for both and slicing like pred_proba[:, 1]
         is needed for positive class predictions
-    predict(X_test, y_test=None, threshold=0.5): class method
-        Return the prediction classes based on the passed threshold.
+
+    predict(X_test, y_test=None, threshold=0.5): instance method
+        Returns the prediction classes based on the passed threshold.
         The default threshold is set at 0.5.
-    get_params(): class method
+
+    get_params(): instance method
         Returns params dict
-    get_intercept(): class method
+
+    get_intercept(): instance method
         Returns model's intercept
-    get_coeffs(): class method
+
+    get_coeffs(): instance method
         Returns non-zero coefficients DataFrame
-    get_cv_results(): class method
+
+    get_cv_results(): instance method
         Returns cross-validation results DataFrame
-    get_results(): class method
+
+    get_results(): instance method
         Returns model's total results dict
 
+    plot_cv_results(): instance method
+        Returns plot of cross-validation results
 
-    plot_feature_importance(): class method
-        Plots feature importance
-    plot_shap_summary(): class method
-        Plot shap values summary
+    plot_coeff_path(): instance method
+        Returns plot of coeff. paths
     """
 
     def __init__(
@@ -1223,12 +1384,14 @@ class GLMNetCVClassifier:
 
     def _dtrain(self, X_train, y_train):
         """
-        Function to preprocess X_test, y_test data as
+        Function to preprocess X_train, y_train data as
         Pandas DataFrame for the sake of postprocessing.
+
         Parameters
         ----------
         X_train: numpy.array or Pandas DataFrame
             Training features data
+
         y_train: numpy.array[int] or list[int]
             List of training ground truth binary values [0, 1]
         """
@@ -1256,10 +1419,12 @@ class GLMNetCVClassifier:
         Pandas DataFrame for the sake of postprocessing.
         Note that y_test is optional since it might not
         be available while validating the model.
+
         Parameters
         ----------
         X_test: numpy.array or Pandas DataFrame
             Testing features data
+
         y_test: numpy.array[int] or list[int]
             List of testing ground truth binary values [0, 1]
         """
@@ -1308,8 +1473,7 @@ class GLMNetCVClassifier:
 
     def _coeff_to_df(self):
         """
-        Function to return the non-zero coeff
-        for the best lambda as Pandas DataFrame.
+        Function to return the non-zero coeff for the best lambda as Pandas DataFrame.
         """
         dct = self._coeff_to_dict()
 
@@ -1321,14 +1485,17 @@ class GLMNetCVClassifier:
 
     def _coeff_to_dict(self):
         """
-        Function to return the non-zero coeff
-        for the best lambda as dict.
+        Function to return the non-zero coeff for the best lambda as dict.
         """
         idx = list(np.nonzero(np.reshape(self.model_.coef_, (1, -1)))[1])
         dct = dict(
             zip(
                 [self.X_train_.columns.tolist()[i] for i in idx],
-                [self.model_.coef_[0][i] for i in idx],
+                [
+                    self.model_.coef_.reshape(-1, self.model_.coef_.shape[-1])[0][i]
+                    for i in idx
+                ],
+                #                 [self.model_.coef_[0][i] for i in idx],
             )
         )
 
@@ -1357,6 +1524,7 @@ class GLMNetCVClassifier:
         results["intercept"] = self.model_.intercept_
         results["intercept_path"] = self.model_.intercept_path_.tolist()[0]
         results["params"] = self.model_.get_params()
+        results["module"] = self.model_.__module__
 
         return results
 
@@ -1394,9 +1562,12 @@ class GLMNetCVClassifier:
     def fit(self, X_train, y_train):
         """
         Function to initialize a LogitNet model using (X, y).
+
+        Parameters
         ----------
-        X_train: numpy.array or Pandas DataFrame
+        X_train: numpy.array or pandas.DataFrame
             Training features data
+
         y_train: numpy.array[int] or list[int]
             List of training ground truth binary values [0, 1]
         """
@@ -1426,12 +1597,15 @@ class GLMNetCVClassifier:
         while the sklearn one returns for both and slicing like pred_proba[:, 1]
         is needed for positive class predictions. Note that y_test is optional while
         it might not be available in validiation.
+
         Parameters
         ----------
-        X_test: numpy.array or Pandas DataFrame
+        X_test: numpy.array or pandas.DataFrame
             Validation features data
+
         y_test: numpy.array[int] or list[int], optional (default=None)
             List of validation ground truth binary values [0, 1]
+
         lamb: array, optional (default=None)
         Values with shape (n_lambda,) of lambda from lambda_path_
         from which to make predictions. If no values are provided (None),
@@ -1457,15 +1631,19 @@ class GLMNetCVClassifier:
         Function to return the prediction classes based on the passed threshold.
         The default threshold is set at 0.5 while you can find the optimum thresholds
         based on different methods using BinaryClassificationMetrics.
+
         Parameters
         ----------
-        X_test: numpy.array or Pandas DataFrame
+        X_test: numpy.array or pandas.DataFrame
             Validation features data
+
         y_test: numpy.array[int] or list[int], optional (default=None)
             List of validation ground truth binary values [0, 1]
+
         threshold: float, optional (default=0.5)
             Threshold to define classes based on probabilities.
             predict_proba >= threshold would be defined as 1 else 0.
+
         lamb: array, optional (default=None)
         Values with shape (n_lambda,) of lambda from lambda_path_
         from which to make predictions. If no values are provided (None),
@@ -1519,76 +1697,163 @@ class GLMNetCVClassifier:
         figsize=None,
         marker=None,
         markersize=None,
-        color=None,
-        errorbarcolor=None,
-        bestlambdacolor=None,
-        maxlambdacolor=None,
+        colors=None,
         linestyle=None,
         fontsize=None,
+        grid=True,
+        legend=True,
         legendloc=None,
+        xlabel=None,
+        ylabel=None,
+        title=None,
+        save_path=None,
     ):
-        """
-        Function to plot cross-validation results.
+        """Function to plot GLMNetCVClassfier cross-validation results.
+
         Parameters
         ----------
         figsize: tuple, optional, (default=(8, 5))
             Figure size
+
         marker: str, optional, (default="o")
             Marker style
             marker style can be found at:
             (https://matplotlib.org/2.1.1/api/markers_api.html#module-matplotlib.markers)
+
         markersize: int or float, optional, (default=5)
             Markersize
-        color: str, optional, (default="red")
-            Color of the line plot
-        errorbarcolor: str, optional (default="black")
-            Color of the error bar of the line plot
-        bestlambdacolor: str, optional (default="navy")
-            Color of the best lambda line
-        maxlambdacolor: str, optional (default="purple")
-            Color of the max lambda line
+
+        colors: list or tuple
+            Colors of the marker, errorbar line, max_lambda line,
+            and best_lambda line, respectively. The default colors
+            are ("red", "black", "purple", "navy"). The length of the
+            passed tuple/list should be always four.
+
         linestyle: str, optional (default="--")
             Linestyle of vertical lambda lines
+
         fontsize: int or float, optional, (default=12)
-            Fontsize for xlabel and ylabel, and ticks parameters
+            Fontsize of the title. The fontsizes of xlabel, ylabel,
+            tick_params, and legend are resized with 0.85, 0.85, 0.75,
+            and 0.85 fraction of title fontsize, respectively.
+
+        grid : bool, optional (default=True)
+            Whether to show (x,y) grid on the plot.
+
+        legend: bool, optional (default=True)
+            Whether to show legend on the plot.
+
         legendloc: int or str, optional (default="best")
             Location of legend
+
+        xlabel : str, optional (default="-Log(Lambda)")
+            Xlabel of the plot.
+
+        ylabel : str, optional (default="{n_splits}-Folds CV Mean {metric}"
+            Ylabel of the plot.
+
+        title : str, optional (default="Best {lambda_best} with {n} Features"
+            Title of the plot.
+
+        save_path: string or None
+            The full or relative path to save the image including the image format.
+            For example "myplot.png" or "../../myplot.pdf"
+
+        Returns None
         """
 
         plot_glmnet_cv_results(
             figsize=figsize,
             marker=marker,
             markersize=markersize,
-            color=color,
-            errorbarcolor=errorbarcolor,
-            bestlambdacolor=bestlambdacolor,
-            maxlambdacolor=maxlambdacolor,
+            colors=colors,
             linestyle=linestyle,
             fontsize=fontsize,
+            grid=grid,
+            legend=legend,
             legendloc=legendloc,
+            xlabel=xlabel,
+            ylabel=ylabel,
+            title=title,
+            save_path=save_path,
             **self.results_,
         )
 
     def plot_coeff_path(
-        self, figsize=None, linestyle=None, fontsize=None, legendloc=None
+        self,
+        figsize=None,
+        linestyle=None,
+        fontsize=None,
+        grid=True,
+        legend=True,
+        legendloc="center",
+        xlabel=None,
+        ylabel=None,
+        title=None,
+        bbox_to_anchor=None,
+        yscale=None,
+        save_path=None,
     ):
         """Function to plot GLMNetCVClassfier coefficients' paths.
+
         Parameters
         ----------
         figsize: tuple, optional, (default=(8, 5))
             Figure size
+
         linestyle: str, optional (default="-")
             Linestyle of vertical lambda lines
+
         fontsize: int or float, optional, (default=12)
-            Fontsize for xlabel and ylabel, and ticks parameters
-        legendloc: int or str, optional (default="center")
-            Location of legend
+            Fontsize of the title. The fontsizes of xlabel, ylabel,
+            tick_params, and legend are resized with 0.85, 0.85, 0.75,
+            and 0.75 fraction of title fontsize, respectively.
+
+        grid : bool, optional (default=True)
+            Whether to show (x,y) grid on the plot.
+
+        legend: bool, optional (default=True)
+            Whether to show legend on the plot.
+
+        legendloc: str, optional (default="center")
+            Legend location.
+
+        xlabel : str, optional (default="-Log(Lambda")
+            Xlabel of the plot.
+
+        ylabel : str, optional (default="Coefficients")
+            Ylabel of the plot.
+
+        title : str, optional (default="Best {lambda_best} with {n} Features")
+            Title of the plot.
+
+        yscale: str, optional (default="linear")
+            Scale for y-axis (coefficients). Valid options are
+            "linear", "log", "symlog", "logit". More on:
+            https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.yscale.html
+
+        bbox_to_anchor: tuple, list, optional (default=(1.2, 0.5)
+            Relative coordinates for legend location outside of the plot.
+
+        save_path: str, optional (default=None)
+            The full or relative path to save the plot including the image format.
+            For example "myplot.png" or "../../myplot.pdf"
+
+        Returns None
         """
 
         plot_glmnet_coeff_path(
             figsize=figsize,
             linestyle=linestyle,
             fontsize=fontsize,
+            grid=grid,
+            legend=legend,
             legendloc=legendloc,
+            xlabel=xlabel,
+            ylabel=ylabel,
+            title=title,
+            bbox_to_anchor=bbox_to_anchor,
+            yscale=yscale,
+            save_path=save_path,
             **self.results_,
         )
